plot_atomic_levels — PyProcar 6.2.1 documentation

Skip to main content
`Ctrl`+`K`

# plot_atomic_levels

EBSPlot.plot_atomic_levels(spins: List[int] | None = None, width_mask: ndarray | None = None, color_mask: ndarray | None = None, width_weights: ndarray | None = None, color_weights: ndarray | None = None, elimit: List[float] | None = None, labels=None)

  A method to plot a scatter plot

  Parameters:

    - spins (List[int], optional) – A list of spins, by default None

    - width_mask (np.ndarray, optional) – The width mask, by default None

    - color_mask (np.ndarray, optional) – The color mask, by default None

    - width_weights (np.ndarray, optional) – The width weight of each point, by default None

    - color_weights (np.ndarray, optional) – The color weights at each point, by default None

    - elimit (List[float], optional) – The energy range to plot.